/*
  SlowRainbow v1

  Produces a Slowly Moving Rainbow Animation Using LEDs.
  
  Board : METE HOCA Akana R1
  Dock  : RGB Matrix Dock Rev.1
  Core  : earlephilhower / arduino-pico (https://github.com/earlephilhower/arduino-pico)
  Required Libraries : U8G2 (https://github.com/olikraus/u8g2)
                       Adafruit NeoPixel (https://github.com/adafruit/Adafruit_NeoPixel)
  Settings: Select METE HOCA Akana R1 as the board.

  Source : mattnupen / METE HOCA
  
  METE HOCA, 19 May 2024
  IG : https://www.instagram.com/metehoca/
  YT : https://www.youtube.com/MeteHoca
  WEB: https://www.metehoca.com/
*/

#include "AkanaLogo.h"
#include <Adafruit_NeoPixel.h>

int bright = 32;
int wait = 50;

Adafruit_NeoPixel neo = Adafruit_NeoPixel(40, 24, NEO_GRB + NEO_KHZ800);

int Wheel(byte WheelPos) {
  if(WheelPos < 85) {
   return neo.Color(WheelPos * 3, 255 - WheelPos * 3, 0);
  } else if(WheelPos < 170) {
   WheelPos -= 85;
   return neo.Color(255 - WheelPos * 3, 0, WheelPos * 3);
  } else {
   WheelPos -= 170;
   return neo.Color(0, WheelPos * 3, 255 - WheelPos * 3);
  }
}

void setup() {
  neo.begin();
  neo.show();
  neo.setBrightness(bright);
  
  logoAkana();
}

void loop() {
  byte i, j;

  for(j = 0; j < 256; j++) {
    for(i = 0; i < neo.numPixels(); i++) {
      neo.setPixelColor(i, Wheel((i + j) & 255));
    }
    neo.show();
    delay(wait);
  }
}